        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,5,6,10,12,13,14,15,16,17,20,22,24,27,29,33,35,36,37,38,42,44,48,49';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 12 <br>7,8,11,26,31,34,40,41,43,46,47,50';}
       if(rr==7 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>32</strong> miembros: 12 <br>1,9,18,19,21,23,25,28,30,32,39,45';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,5,6,10,12,13,14,15,16,17,20,22,24,27,29,33,35,36,37,38,42,44,48,49';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 12 <br>7,8,11,26,31,34,40,41,43,46,47,50';}
       if(rr==34 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>32</strong> miembros: 12 <br>1,9,18,19,21,23,25,28,30,32,39,45';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,5,6,10,12,13,14,15,16,17,20,22,24,27,29,33,35,36,37,38,42,44,48,49';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 12 <br>7,8,11,26,31,34,40,41,43,46,47,50';}
       if(rr==35 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>32</strong> miembros: 12 <br>1,9,18,19,21,23,25,28,30,32,39,45';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,5,6,10,12,13,14,15,16,17,20,22,24,27,29,33,35,36,37,38,42,44,48,49';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 12 <br>7,8,11,26,31,34,40,41,43,46,47,50';}
       if(rr==36 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>32</strong> miembros: 12 <br>1,9,18,19,21,23,25,28,30,32,39,45';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,5,6,10,12,13,14,15,16,17,20,22,24,27,29,33,35,36,37,38,42,44,48,49';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 12 <br>7,8,11,26,31,34,40,41,43,46,47,50';}
       if(rr==37 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>32</strong> miembros: 12 <br>1,9,18,19,21,23,25,28,30,32,39,45';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,5,6,10,12,13,14,15,16,17,20,22,24,27,29,33,35,36,37,38,42,44,48,49';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 12 <br>7,8,11,26,31,34,40,41,43,46,47,50';}
       if(rr==38 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>32</strong> miembros: 12 <br>1,9,18,19,21,23,25,28,30,32,39,45';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,5,6,10,12,13,14,15,16,17,20,22,24,27,29,33,35,36,37,38,42,44,48,49';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 12 <br>7,8,11,26,31,34,40,41,43,46,47,50';}
       if(rr==39 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>32</strong> miembros: 12 <br>1,9,18,19,21,23,25,28,30,32,39,45';}
}
